from django import template
from django.template.defaultfilters import stringfilter
from django.utils.safestring import mark_safe

register = template.Library()

def obfuscate_string(value):
    return ''.join(['&#%s;' % str(ord(char)) for char in value])


@register.filter()
@stringfilter
def obfuscate(value):
    return mark_safe(obfuscate_string(value))

@register.filter()
@stringfilter
def obfuscate_mailto(value):
    mail = obfuscate_string(value)
    return mark_safe('<a href="%s%s">%s</a>' % (obfuscate_string('mailto:'), mail, mail))


from distutils.core import setup

setup(name='django-email-obfuscator',
    version='0.1.1',
    description='A Django template filter to protect email addresses from \
    crawlers.',
    author='Joseph Mornin',
    author_email='joseph@mornin.org',
    url='https://github.com/morninj/django-email-obfuscator',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
    packages=['email_obfuscator'],
    package_data = {
        'email_obfuscator': [
            'templatetags/*',
        ],
    },
    )
